@@ -454,6 +454,7 @@ phonemgr_listener_connect (PhonemgrListener *l, const char *device, GError **err
 		channel = phonemgr_utils_get_serial_channel (device);
 		if (channel < 0) {
 			//FIXME
+			phonemgr_listener_emit_status (l, PHONEMGR_LISTENER_ERROR);
 			return FALSE;
 		}
 	}
@@ -462,6 +463,7 @@ phonemgr_listener_connect (PhonemgrListener *l, const char *device, GError **err
 	l->phone_state = phonemgr_utils_connect (device, NULL, channel, l->debug, error);
 	if (l->phone_state == NULL) {
 		//FIXME
+		phonemgr_listener_emit_status (l, PHONEMGR_LISTENER_ERROR);
 		return FALSE;
 	}
 
@@ -471,6 +473,7 @@ phonemgr_listener_connect (PhonemgrListener *l, const char *device, GError **err
 		//FIXME
 		phonemgr_utils_disconnect (l->phone_state);
 		phonemgr_utils_free (l->phone_state);
+		phonemgr_listener_emit_status (l, PHONEMGR_LISTENER_ERROR);
 		return FALSE;
 	}
 
@@ -484,6 +487,7 @@ phonemgr_listener_connect (PhonemgrListener *l, const char *device, GError **err
 			l->driver = NULL;
 			//FIXME
 			g_message ("Couldn't connect to the device, gnapplet needed but not running");
+			phonemgr_listener_emit_status (l, PHONEMGR_LISTENER_ERROR);
 			return FALSE;
 		}
 	}
@@ -498,6 +502,7 @@ phonemgr_listener_connect (PhonemgrListener *l, const char *device, GError **err
 		l->phone_state = phonemgr_utils_connect (device, l->driver, channel, l->debug, error);
 		if (l->phone_state == NULL) {
 			//FIXME
+			phonemgr_listener_emit_status (l, PHONEMGR_LISTENER_ERROR);
 			return FALSE;
 		}
 	}
@@ -549,7 +554,7 @@ phonemgr_listener_push (PhonemgrListener *l)
 		g_message ("emitting battery");
 		phonemgr_listener_emit_battery (l,
 						(int) signal->battery->batterylevel,
-						signal->battery->powersource != GN_PS_BATTERY);
+						signal->battery->powersource == GN_PS_ACDC);
 		g_free (signal->battery);
 		break;
 	case NETWORK_SIGNAL:
@@ -1131,6 +1136,8 @@ phonemgr_listener_queue_message (PhonemgrListener *l,
 	error = gn_sms_send (&l->phone_state->data, &l->phone_state->state);
 
 	/* Remove the reference to SMS */
+	if (l->phone_state->data.sms->reference != NULL)
+		free (l->phone_state->data.sms->reference);
 	l->phone_state->data.sms = NULL;
 
 	/* Unlock the phone */
